==> cloudstructs-0.4.17-py3-none-any.whl: package/assets/toolkit-cleaner/extract-template-hashes.lambda/index.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __markAsModule = (target) => __defProp(target, "__esModule", { value: true });
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __reExport = (target, module2, copyDefault, desc) => {
  if (module2 && typeof module2 === "object" || typeof module2 === "function") {
    for (let key of __getOwnPropNames(module2))
      if (!__hasOwnProp.call(target, key) && (copyDefault || key !== "default"))
        __defProp(target, key, { get: () => module2[key], enumerable: !(desc = __getOwnPropDesc(module2, key)) || desc.enumerable });
  }
  return target;
};
var __toCommonJS = /* @__PURE__ */ ((cache) => {
  return (module2, temp) => {
    return cache && cache.get(module2) || (temp = __reExport(__markAsModule({}), module2, 1), cache && cache.set(module2, temp), temp);
  };
})(typeof WeakMap !== "undefined" ? /* @__PURE__ */ new WeakMap() : 0);

// src/toolkit-cleaner/extract-template-hashes.lambda.ts
var extract_template_hashes_lambda_exports = {};
__export(extract_template_hashes_lambda_exports, {
  handler: () => handler
});
var import_aws_sdk = require("aws-sdk");
var cloudFormation = new import_aws_sdk.CloudFormation();
async function handler(stackName) {
  const template = await cloudFormation.getTemplate({
    StackName: stackName
  }).promise();
  if (!template.TemplateBody) {
    return [];
  }
  const hashes = template.TemplateBody.match(/[a-f0-9]{64}/g);
  return [...new Set(hashes)];
}
module.exports = __toCommonJS(extract_template_hashes_lambda_exports);
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});

==> cloudstructs-0.5.7-py3-none-any.whl: package/assets/toolkit-cleaner/extract-template-hashes.lambda/index.js <==
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);

// src/toolkit-cleaner/extract-template-hashes.lambda.ts
var extract_template_hashes_lambda_exports = {};
__export(extract_template_hashes_lambda_exports, {
  handler: () => handler
});
module.exports = __toCommonJS(extract_template_hashes_lambda_exports);
var import_aws_sdk = require("aws-sdk");
var cloudFormation = new import_aws_sdk.CloudFormation();
async function handler(stackName) {
  const template = await cloudFormation.getTemplate({
    StackName: stackName
  }).promise();
  if (!template.TemplateBody) {
    return [];
  }
  const hashes = template.TemplateBody.match(/[a-f0-9]{64}/g);
  return [...new Set(hashes)];
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  handler
});
